==> zabbix-frontend-php-5.0.3-1-aarch64.pkg.tar.xz: usr/share/webapps/zabbix/app/views/monitoring.widget.favgraphs.view.php <==
<?php
/*
** Zabbix
** Copyright (C) 2001-2020 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
**/


/**
 * @var CView $this
 */

$table = (new CTableInfo())->setNoDataMessage(_('No graphs added.'));

foreach ($data['graphs'] as $graph) {
	$url = $graph['simple']
		? (new CUrl('history.php'))
			->setArgument('action', HISTORY_GRAPH)
			->setArgument('itemids', [$graph['itemid']])
		: (new CUrl('zabbix.php'))
			->setArgument('action', 'charts.view')
			->setArgument('view_as', HISTORY_GRAPH)
			->setArgument('filter_search_type', ZBX_SEARCH_TYPE_STRICT)
			->setArgument('filter_graphids', [$graph['graphid']])
			->setArgument('filter_set', '1');

	$on_click = $graph['simple']
		? "rm4favorites('itemid','".$graph['itemid']."')"
		: "rm4favorites('graphid','".$graph['graphid']."')";

	$table->addRow([
		new CLink($graph['label'], $url),
		(new CButton())
			->onClick($on_click)
			->addClass(ZBX_STYLE_REMOVE_BTN)
			->setAttribute('aria-label', _xs('Remove, %1$s', 'screen reader', $graph['label']))
			->removeId()
	]);
}

$output = [
	'header' => $data['name'],
	'body' => $table->toString()
];

if (($messages = getMessages()) !== null) {
	$output['messages'] = $messages->toString();
}

if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
	CProfiler::getInstance()->stop();
	$output['debug'] = CProfiler::getInstance()->make()->toString();
}

echo json_encode($output);

==> zabbix-frontend-php-5.4.10-1-aarch64.pkg.tar.xz: usr/share/webapps/zabbix/app/views/monitoring.widget.favgraphs.view.php <==
<?php
/*
** Zabbix
** Copyright (C) 2001-2022 Zabbix SIA
**
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
** GNU General Public License for more details.
**
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
**/


/**
 * @var CView $this
 */

$table = (new CTableInfo())->setNoDataMessage(_('No graphs added.'));

foreach ($data['graphs'] as $graph) {
	$url = $graph['simple']
		? (new CUrl('history.php'))
			->setArgument('action', HISTORY_GRAPH)
			->setArgument('itemids', [$graph['itemid']])
		: (new CUrl('zabbix.php'))
			->setArgument('action', 'charts.view')
			->setArgument('view_as', HISTORY_GRAPH)
			->setArgument('filter_search_type', ZBX_SEARCH_TYPE_STRICT)
			->setArgument('filter_graphids', [$graph['graphid']])
			->setArgument('filter_set', '1');

	$on_click = $graph['simple']
		? "rm4favorites('itemid','".$graph['itemid']."')"
		: "rm4favorites('graphid','".$graph['graphid']."')";

	$table->addRow([
		($graph['simple'] && $data['allowed_ui_latest_data']) || (!$graph['simple'] && $data['allowed_ui_hosts'])
			? new CLink($graph['label'], $url)
			: $graph['label'],
		(new CButton())
			->onClick($on_click)
			->addClass(ZBX_STYLE_REMOVE_BTN)
			->setAttribute('aria-label', _xs('Remove, %1$s', 'screen reader', $graph['label']))
			->removeId()
	]);
}

$output = [
	'name' => $data['name'],
	'body' => $table->toString()
];

if (($messages = getMessages()) !== null) {
	$output['messages'] = $messages->toString();
}

if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
	CProfiler::getInstance()->stop();
	$output['debug'] = CProfiler::getInstance()->make()->toString();
}

echo json_encode($output);
